Security Advisories (2)
CVE-2022-23935 (2022-01-25)

lib/Image/ExifTool.pm in ExifTool before 12.38 mishandles a $file =~ /\|$/ check, leading to command injection.

CVE-2021-22204 (2021-04-23)

Improper neutralization of user data in the DjVu file format in ExifTool versions 7.44 and up allows arbitrary code execution when parsing the malicious image

NAME

Image::ExifTool::WriteQuickTime.pl - Write XMP to QuickTime (MOV and MP4) files

SYNOPSIS

These routines are autoloaded by Image::ExifTool::QuickTime.

DESCRIPTION

This file contains routines used by ExifTool to write XMP metadata to QuickTime-based file formats like MOV and MP4.

AUTHOR

Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

SEE ALSO

Image::ExifTool::QuickTime(3pm), Image::ExifTool(3pm)